@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: io90pwm316.h,v 1.7.2.4 2008/02/21 18:07:29 arcanum Exp $ */
+/* $Id: io90pwm316.h,v 1.7.2.8 2009/02/11 18:05:24 arcanum Exp $ */
 
 /* avr/io90pwm316.h - definitions for AT90PWM316 */
 
@@ -1165,8 +1165,9 @@
 
 #define RAMEND         0x4FF
 #define XRAMSIZE       0
-#define XRAMEND        (RAMEND + XRAMSIZE)
+#define XRAMEND        RAMEND
 #define E2END          0x1FF
+#define E2PAGESIZE     4
 #define FLASHEND       0x3FFF
 #define SPM_PAGESIZE   128
 
@@ -1176,35 +1177,35 @@
 #define FUSE_MEMORY_SIZE 3
 
 /* Low Fuse Byte */
-#define FUSE_CKSEL0  ~_BV(0)  /* Select Clock Source */
-#define FUSE_CKSEL1  ~_BV(1)  /* Select Clock Source */
-#define FUSE_CKSEL2  ~_BV(2)  /* Select Clock Source */
-#define FUSE_CKSEL3  ~_BV(3)  /* Select Clock Source */
-#define FUSE_SUT0    ~_BV(4)  /* Select start-up time */
-#define FUSE_SUT1    ~_BV(5)  /* Select start-up time */
-#define FUSE_CKOUT   ~_BV(6)  /* Oscillator output option */
-#define FUSE_CKDIV8  ~_BV(7)  /* Divide clock by 8 */
+#define FUSE_CKSEL0  (unsigned char)~_BV(0)  /* Select Clock Source */
+#define FUSE_CKSEL1  (unsigned char)~_BV(1)  /* Select Clock Source */
+#define FUSE_CKSEL2  (unsigned char)~_BV(2)  /* Select Clock Source */
+#define FUSE_CKSEL3  (unsigned char)~_BV(3)  /* Select Clock Source */
+#define FUSE_SUT0    (unsigned char)~_BV(4)  /* Select start-up time */
+#define FUSE_SUT1    (unsigned char)~_BV(5)  /* Select start-up time */
+#define FUSE_CKOUT   (unsigned char)~_BV(6)  /* Oscillator output option */
+#define FUSE_CKDIV8  (unsigned char)~_BV(7)  /* Divide clock by 8 */
 #define LFUSE_DEFAULT (FUSE_CKSEL0 & FUSE_CKSEL2 & FUSE_CKSEL3 & FUSE_SUT0 & FUSE_CKDIV8)
 
 /* High Fuse Byte */
-#define FUSE_BODLEVEL0 ~_BV(0)
-#define FUSE_BODLEVEL1 ~_BV(1)
-#define FUSE_BODLEVEL2 ~_BV(2)
-#define FUSE_EESAVE    ~_BV(3)  /* EEPROM memory is preserved through chip erase */
-#define FUSE_WDTON     ~_BV(4)  /* Watchdog timer always on */
-#define FUSE_SPIEN     ~_BV(5)  /* Enable Serial programming and Data Downloading */
-#define FUSE_DWEN      ~_BV(6)  /* debugWIRE Enable */
-#define FUSE_RSTDISBL  ~_BV(7)  /* External Reset Diasble */
+#define FUSE_BODLEVEL0 (unsigned char)~_BV(0)
+#define FUSE_BODLEVEL1 (unsigned char)~_BV(1)
+#define FUSE_BODLEVEL2 (unsigned char)~_BV(2)
+#define FUSE_EESAVE    (unsigned char)~_BV(3)  /* EEPROM memory is preserved through chip erase */
+#define FUSE_WDTON     (unsigned char)~_BV(4)  /* Watchdog timer always on */
+#define FUSE_SPIEN     (unsigned char)~_BV(5)  /* Enable Serial programming and Data Downloading */
+#define FUSE_DWEN      (unsigned char)~_BV(6)  /* debugWIRE Enable */
+#define FUSE_RSTDISBL  (unsigned char)~_BV(7)  /* External Reset Diasble */
 #define HFUSE_DEFAULT (FUSE_SPIEN)
 
 /* Extended Fuse Byte */
-#define FUSE_BOOTRST  ~_BV(0)  /* Select Reset Vector */
-#define FUSE_BOOTSZ0  ~_BV(1)  /* Select Boot Size */
-#define FUSE_BOOTSZ1  ~_BV(2)  /* Select Boot Size */
-#define FUSE_PSCRV    ~_BV(4)
-#define FUSE_PSC0RB   ~_BV(5)
-#define FUSE_PSC1RB   ~_BV(6)
-#define FUSE_PSC2RB   ~_BV(7)
+#define FUSE_BOOTRST  (unsigned char)~_BV(0)  /* Select Reset Vector */
+#define FUSE_BOOTSZ0  (unsigned char)~_BV(1)  /* Select Boot Size */
+#define FUSE_BOOTSZ1  (unsigned char)~_BV(2)  /* Select Boot Size */
+#define FUSE_PSCRV    (unsigned char)~_BV(4)
+#define FUSE_PSC0RB   (unsigned char)~_BV(5)
+#define FUSE_PSC1RB   (unsigned char)~_BV(6)
+#define FUSE_PSC2RB   (unsigned char)~_BV(7)
 #define EFUSE_DEFAULT (FUSE_BOOTSZ0 & FUSE_BOOTSZ1)
 
 
@@ -1214,4 +1215,10 @@
 #define __BOOT_LOCK_BITS_1_EXIST 
 
 
+/* Signature */
+#define SIGNATURE_0 0x1E
+#define SIGNATURE_1 0x94
+#define SIGNATURE_2 0x83
+
+
 #endif /* _AVR_IO90PWM316_H_ */
