@@ -1,4 +1,4 @@
-/* Copyright (c) 2005, 2006 Anatoly Sokolov
+/* Copyright (c) 2005, 2006, 2007 Anatoly Sokolov
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -30,7 +30,7 @@
 
 /* avr/iomXX4.h - definitions for ATmega164P/324P/644P and ATmega644 */
 
-/* $Id: iomxx4.h,v 1.9.2.1 2006/04/19 16:53:25 aesok Exp $ */
+/* $Id: iomxx4.h,v 1.13.2.5 2009/02/06 23:32:02 arcanum Exp $ */
 
 #ifndef _AVR_IOMXX4_H_
 #define _AVR_IOMXX4_H_ 1
@@ -264,22 +264,22 @@
 
 #define GPIOR2	_SFR_IO8(0x2B)
 
-#define SPCR0	_SFR_IO8(0x2C)
-#define SPIE0	7
-#define SPE0	6
-#define DORD0	5
-#define MSTR0	4
-#define CPOL0	3
-#define CPHA0	2
-#define SPR01	1
-#define SPR00	0
+#define SPCR	_SFR_IO8(0x2C)
+#define SPIE	7
+#define SPE	6
+#define DORD	5
+#define MSTR	4
+#define CPOL	3
+#define CPHA	2
+#define SPR1	1
+#define SPR0	0
 
-#define SPSR0	_SFR_IO8(0x2D)
-#define SPIF0	7
-#define WCOL0	6
-#define SPI2X0	0
+#define SPSR	_SFR_IO8(0x2D)
+#define SPIF	7
+#define WCOL	6
+#define SPI2X	0
 
-#define SPDR0	_SFR_IO8(0X2E)
+#define SPDR	_SFR_IO8(0x2E)
 
 /* Reserved [0x2F] */
 
@@ -322,6 +322,10 @@
 
 #define MCUCR	_SFR_IO8(0X35)
 #define JTD	7
+#if !defined(__AVR_ATmega644__)
+#define BODS    6
+#define BODSE   5
+#endif
 #define PUD	4
 #define IVSEL	1
 #define IVCE	0
@@ -362,7 +366,9 @@
 
 /* Reserved [0x62..0x63] */
 
-#define PRR0	_SFR_MEM8(0x64)
+#define PRR	_SFR_MEM8(0x64)  /* Datasheets: ATmega164P/324P/644P 8011DAVR02/07
+                                   and ATmega644 2593LAVR02/07.  */
+#define PRR0	_SFR_MEM8(0x64)  /* AVR Studio 4.13, build 524.  */
 #define PRTWI		7
 #define PRTIM2		6
 #define PRTIM0		5
@@ -661,6 +667,7 @@
 #define USBS0	3
 #define UCSZ01	2
 #define UCSZ00	1
+#define UCPHA0  1
 #define UCPOL0	0
 
 /* Reserved [0xC3] */
@@ -675,7 +682,7 @@
 
 #if !defined(__AVR_ATmega644__)
 /*
- * Only ATmega164/324 have a second USART.
+ * Only ATmega164P/324P/644P have a second USART.
  */
 /* Reserved [0xC7] */
 
@@ -707,6 +714,7 @@
 #define USBS1	3
 #define UCSZ11	2
 #define UCSZ10	1
+#define UCPHA1  1
 #define UCPOL1	0
 
 /* Reserved [0xCB] */
@@ -839,14 +847,17 @@
 #else /* !defined(__AVR_ATmega644__) */
 
 /* USART1, Rx Complete */
+/* USART1 RX complete */
 #define USART1_RX_vect			_VECTOR(28)
 #define SIG_USART1_RECV			_VECTOR(28)
 
 /* USART1 Data register Empty */
+/* USART1 Data Register Empty */
 #define USART1_UDRE_vect		_VECTOR(29)
 #define SIG_USART1_DATA			_VECTOR(29)
 
 /* USART1, Tx Complete */
+/* USART1 TX complete */
 #define USART1_TX_vect			_VECTOR(30)
 #define SIG_USART1_TRANS		_VECTOR(30)
 
