@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iousb646.h,v 1.2.2.1 2008/01/05 00:08:45 arcanum Exp $ */
+/* $Id: iousb646.h,v 1.2.2.4 2008/10/17 23:27:53 arcanum Exp $ */
 
 /* avr/iousb646.h - definitions for AT90USB646 */
 
@@ -38,44 +38,44 @@
 #include <avr/iousbxx6_7.h>
 
 /* Constants */
-#define SPM_PAGESIZE    256
-#define RAMEND          0x10FF
-#define XRAMEND         0xFFFF
-#define E2END           0x7FF
-#define FLASHEND        0xFFFF
+#define SPM_PAGESIZE 256
+#define RAMEND       0x10FF
+#define XRAMEND      0xFFFF
+#define E2END        0x7FF
+#define E2PAGESIZE   8
+#define FLASHEND     0xFFFF
 
 
 /* Fuses */
-
 #define FUSE_MEMORY_SIZE 3
 
 /* Low Fuse Byte */
-#define FUSE_CKSEL0      ~_BV(0)
-#define FUSE_CKSEL1      ~_BV(1)
-#define FUSE_CKSEL2      ~_BV(2)
-#define FUSE_CKSEL3      ~_BV(3)
-#define FUSE_SUT0        ~_BV(4)
-#define FUSE_SUT1        ~_BV(5)
-#define FUSE_CKOUT       ~_BV(6)
-#define FUSE_CKDIV8      ~_BV(7)
+#define FUSE_CKSEL0      (unsigned char)~_BV(0)
+#define FUSE_CKSEL1      (unsigned char)~_BV(1)
+#define FUSE_CKSEL2      (unsigned char)~_BV(2)
+#define FUSE_CKSEL3      (unsigned char)~_BV(3)
+#define FUSE_SUT0        (unsigned char)~_BV(4)
+#define FUSE_SUT1        (unsigned char)~_BV(5)
+#define FUSE_CKOUT       (unsigned char)~_BV(6)
+#define FUSE_CKDIV8      (unsigned char)~_BV(7)
 #define LFUSE_DEFAULT (CKSEL0 & CKSEL2 & CKSEL3 & SUT0 & CKDIV8)
 
 /* High Fuse Byte */
-#define FUSE_BOOTRST     ~_BV(0)
-#define FUSE_BOOTSZ0     ~_BV(1)
-#define FUSE_BOOTSZ1     ~_BV(2)
-#define FUSE_EESAVE      ~_BV(3)
-#define FUSE_WDTON       ~_BV(4)
-#define FUSE_SPIEN       ~_BV(5)
-#define FUSE_JTAGEN      ~_BV(6)
-#define FUSE_OCDEN       ~_BV(7)
+#define FUSE_BOOTRST     (unsigned char)~_BV(0)
+#define FUSE_BOOTSZ0     (unsigned char)~_BV(1)
+#define FUSE_BOOTSZ1     (unsigned char)~_BV(2)
+#define FUSE_EESAVE      (unsigned char)~_BV(3)
+#define FUSE_WDTON       (unsigned char)~_BV(4)
+#define FUSE_SPIEN       (unsigned char)~_BV(5)
+#define FUSE_JTAGEN      (unsigned char)~_BV(6)
+#define FUSE_OCDEN       (unsigned char)~_BV(7)
 #define HFUSE_DEFAULT (BOOTSZ0 & BOOTSZ1 & SPIEN & JTAGEN)
 
 /* Extended Fuse Byte */
-#define FUSE_BODLEVEL0   ~_BV(0)
-#define FUSE_BODLEVEL1   ~_BV(1)
-#define FUSE_BODLEVEL2   ~_BV(2)
-#define FUSE_HWBE        ~_BV(3)
+#define FUSE_BODLEVEL0   (unsigned char)~_BV(0)
+#define FUSE_BODLEVEL1   (unsigned char)~_BV(1)
+#define FUSE_BODLEVEL2   (unsigned char)~_BV(2)
+#define FUSE_HWBE        (unsigned char)~_BV(3)
 #define EFUSE_DEFAULT (BODLEVEL2 & HWBE)
 
 
@@ -85,4 +85,10 @@
 #define __BOOT_LOCK_BITS_1_EXIST 
 
 
+/* Signature */
+#define SIGNATURE_0 0x1E
+#define SIGNATURE_1 0x96
+#define SIGNATURE_2 0x82
+
+
 #endif /* _AVR_AT90USB646_H_ */
