@@ -1,5 +1,5 @@
 /* Copyright (c) 2002, Marek Michalkiewicz
-   Copyright (c) 2004, Joerg Wunsch
+   Copyright (c) 2004,2007 Joerg Wunsch
 
    Portions of documentation Copyright (c) 1990, 1991, 1993, 1994
    The Regents of the University of California.
@@ -33,7 +33,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
 
-  $Id: stdlib.h,v 1.24 2005/09/13 13:29:54 joerg_wunsch Exp $
+  $Id: stdlib.h,v 1.33.2.2 2008/03/16 13:44:44 dmix Exp $
 */
 
 #ifndef _STDLIB_H_
@@ -54,6 +54,8 @@
 extern "C" {
 #endif
 
+/** \file */
+
 /** \defgroup avr_stdlib <stdlib.h>: General utilities
     \code #include <stdlib.h> \endcode
 
@@ -97,16 +99,11 @@ typedef int (*__compar_fn_t)(const void *, const void *);
 
 #endif
 
-extern __inline__ void abort(void) __ATTR_NORETURN__;
-
 /** The abort() function causes abnormal program termination to occur.
-    In the limited AVR environment, execution is effectively halted
-    by entering an infinite loop. */
-extern __inline__ void
-abort(void)
-{
-	for (;;);
-}
+    This realization disables interrupts and jumps to _exit() function
+    with argument equal to 1. In the limited AVR environment, execution is
+    effectively halted by entering an infinite loop. */
+extern void abort(void) __ATTR_NORETURN__;
 
 /** The abs() function computes the absolute value of the integer \c i.
    \note The abs() and labs() functions are builtins of gcc.
@@ -246,44 +243,34 @@ extern unsigned long strtoul(const char *__nptr, char **__endptr, int __base);
 
 /**
     The atol() function converts the initial portion of the string
-    pointed to by \c nptr to long integer representation.
+    pointed to by \p s to long integer representation. In contrast to
 
-    It is equivalent to:
+        \code strtol(s, (char **)NULL, 10); \endcode
 
-           \code strtol(nptr, (char **)NULL, 10); \endcode
+    this function does not detect overflow (\c errno is not changed and
+    the result value is not predictable), uses smaller memory (flash and
+    stack) and works more quickly.
 */
-extern __inline__ long atol(const char *__nptr) __ATTR_PURE__;
-extern __inline__ long
-atol(const char *__nptr)
-{
-	return strtol(__nptr, (char **) 0, 10);
-}
+extern long atol(const char *__s) __ATTR_PURE__;
 
 /**
     The atoi() function converts the initial portion of the string
-    pointed to by \c nptr to integer representation.
+    pointed to by \p s to integer representation. In contrast to
 
-    It is equivalent to:
+        \code (int)strtol(s, (char **)NULL, 10); \endcode
 
-           \code (int)strtol(nptr, (char **)NULL, 10); \endcode
+    this function does not detect overflow (\c errno is not changed and
+    the result value is not predictable), uses smaller memory (flash and
+    stack) and works more quickly.
 */
-#ifdef __DOXYGEN__
-extern __inline__ int atoi(const char *__nptr) __ATTR_PURE__;
-extern __inline__ int
-atoi(const char *__nptr)
-{
-	return (int) atol(__nptr);
-}
-#else
-/* optimized asm version, much smaller if strtol() not used elsewhere */
-extern int atoi(const char *) __ATTR_PURE__;
-#endif
+extern int atoi(const char *__s) __ATTR_PURE__;
 
 /**
    The exit() function terminates the application.  Since there is no
    environment to return to, \c status is ignored, and code execution
    will eventually reach an infinite loop, thereby effectively halting
-   all code processing.
+   all code processing.  Before entering the infinite loop, interrupts
+   are globally disabled.
 
    In a C++ context, global destructors will be called before halting
    execution.
@@ -350,47 +337,8 @@ extern void *calloc(size_t __nele, size_t __size) __ATTR_MALLOC__;
 */
 extern void *realloc(void *__ptr, size_t __size) __ATTR_MALLOC__;
 
-/**
-     The strtod() function converts the initial portion of the string pointed
-     to by \c nptr to double representation.
-
-     The expected form of the string is an optional plus ( \c '+' ) or minus sign
-     ( \c '-' ) followed by a sequence of digits optionally containing a
-     decimal-point character, optionally followed by an exponent.  An exponent
-     consists of an \c 'E' or \c 'e', followed by an optional plus or minus
-     sign, followed by a sequence of digits.
-
-     Leading white-space characters in the string are skipped.
-
-     The strtod() function returns the converted value, if any.
-
-     If \c endptr is not \c NULL, a pointer to the character after the last
-     character used in the conversion is stored in the location referenced by
-     \c endptr.
-
-     If no conversion is performed, zero is returned and the value of \c nptr is
-     stored in the location referenced by \c endptr.
-
-     If the correct value would cause overflow, plus or minus \c HUGE_VAL is
-     returned (according to the sign of the value), and \c ERANGE is stored in
-     \c errno.  If the correct value would cause underflow, zero is returned and
-     \c ERANGE is stored in \c errno.
-
-     FIXME: HUGE_VAL needs to be defined somewhere.  The bit pattern is
-     0x7fffffff, but what number would this be?
- */
-
 extern double strtod(const char *__nptr, char **__endptr);
 
-/**
-     The atof() function converts the initial portion of the string pointed
-     to by \c nptr to double representation.
-
-     It is equivalent to calling
-
-     		\code strtod(nptr, (char **)NULL); \endcode
- */
-
 extern double atof(const char *__nptr);
 
 /** Highest number that can be generated by rand(). */
@@ -424,7 +372,7 @@ extern void srand(unsigned int __seed);
    variable located at \c ctx instead of a static library variable
    so the function becomes re-entrant.
 */
-extern int rand_r(unsigned long *ctx);
+extern int rand_r(unsigned long *__ctx);
 /*@}*/
 
 /*@{*/
@@ -566,7 +514,7 @@ extern void srandom(unsigned long __seed);
    variable located at \c ctx instead of a static library variable
    so the function becomes re-entrant.
 */
-extern long random_r(unsigned long *ctx);
+extern long random_r(unsigned long *__ctx);
 #endif /* __ASSEMBLER */
 /*@}*/
 
@@ -578,16 +526,20 @@ extern long random_r(unsigned long *ctx);
  So when linking the application, the \c -lm option needs to be
  specified.
 */
-/** Bit value that can be passed in \c flags to dtostre(). */
+/** \ingroup avr_stdlib
+    Bit value that can be passed in \c flags to dtostre(). */
 #define DTOSTR_ALWAYS_SIGN 0x01        /* put '+' or ' ' for positives */
-/** Bit value that can be passed in \c flags to dtostre(). */
+/** \ingroup avr_stdlib
+    Bit value that can be passed in \c flags to dtostre(). */
 #define DTOSTR_PLUS_SIGN   0x02        /* put '+' rather than ' ' */
-/** Bit value that can be passed in \c flags to dtostre(). */
+/** \ingroup avr_stdlib
+    Bit value that can be passed in \c flags to dtostre(). */
 #define DTOSTR_UPPERCASE   0x04        /* put 'E' rather 'e' */
 
 #ifndef __ASSEMBLER__
 
 /**
+   \ingroup avr_stdlib
    The dtostre() function converts the double value passed in \c val into
    an ASCII representation that will be stored under \c s.  The caller
    is responsible for providing sufficient storage in \c s.
@@ -612,6 +564,7 @@ extern char *dtostre(double __val, char *__s, unsigned char __prec,
 		     unsigned char __flags);
 
 /**
+   \ingroup avr_stdlib
    The dtostrf() function converts the double value passed in \c val into
    an ASCII representationthat will be stored under \c s.  The caller
    is responsible for providing sufficient storage in \c s.
@@ -619,11 +572,13 @@ extern char *dtostre(double __val, char *__s, unsigned char __prec,
    Conversion is done in the format \c "[-]d.ddd".  The minimum field
    width of the output string (including the \c '.' and the possible
    sign for negative values) is given in \c width, and \c prec determines
-   the number of digits after the decimal sign.
+   the number of digits after the decimal sign. \c width is signed value,
+   negative for left adjustment.
 
    The dtostrf() function returns the pointer to the converted string \c s.
 */
-extern char *dtostrf(double __val, char __width, char __prec, char *__s);
+extern char *dtostrf(double __val, signed char __width,
+                     unsigned char __prec, char *__s);
 
 /*@}*/
 
